@@ -147,7 +147,8 @@ from .delete_script_by_hash_response_200_language import DeleteScriptByHashRespo
 from .delete_script_by_hash_response_200_schema import DeleteScriptByHashResponse200Schema
 from .deno_to_jsonschema_response_200 import DenoToJsonschemaResponse200
 from .deno_to_jsonschema_response_200_args_item import DenoToJsonschemaResponse200ArgsItem
-from .deno_to_jsonschema_response_200_args_item_typ import DenoToJsonschemaResponse200ArgsItemTyp
+from .deno_to_jsonschema_response_200_args_item_typ_type_0 import DenoToJsonschemaResponse200ArgsItemTypType0
+from .deno_to_jsonschema_response_200_args_item_typ_type_1 import DenoToJsonschemaResponse200ArgsItemTypType1
 from .edit_resource import EditResource
 from .edit_resource_type import EditResourceType
 from .edit_resource_value import EditResourceValue
@@ -509,7 +510,8 @@ from .login import Login
 from .login_json_body import LoginJsonBody
 from .main_arg_signature import MainArgSignature
 from .main_arg_signature_args_item import MainArgSignatureArgsItem
-from .main_arg_signature_args_item_typ import MainArgSignatureArgsItemTyp
+from .main_arg_signature_args_item_typ_type_0 import MainArgSignatureArgsItemTypType0
+from .main_arg_signature_args_item_typ_type_1 import MainArgSignatureArgsItemTypType1
 from .new_schedule import NewSchedule
 from .new_schedule_args import NewScheduleArgs
 from .new_token import NewToken
@@ -520,7 +522,8 @@ from .preview_language import PreviewLanguage
 from .preview_schedule_json_body import PreviewScheduleJsonBody
 from .python_to_jsonschema_response_200 import PythonToJsonschemaResponse200
 from .python_to_jsonschema_response_200_args_item import PythonToJsonschemaResponse200ArgsItem
-from .python_to_jsonschema_response_200_args_item_typ import PythonToJsonschemaResponse200ArgsItemTyp
+from .python_to_jsonschema_response_200_args_item_typ_type_0 import PythonToJsonschemaResponse200ArgsItemTypType0
+from .python_to_jsonschema_response_200_args_item_typ_type_1 import PythonToJsonschemaResponse200ArgsItemTypType1
 from .queued_job import QueuedJob
 from .queued_job_args import QueuedJobArgs
 from .queued_job_flow_status import QueuedJobFlowStatus
