@@ -9,10 +9,7 @@ T = TypeVar("T", bound="EditWorkspaceUser")
 
 @attr.s(auto_attribs=True)
 class EditWorkspaceUser:
-    """
-    Attributes:
-        is_admin (Union[Unset, bool]):
-    """
+    """ """
 
     is_admin: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
