@@ -7,11 +7,7 @@ T = TypeVar("T", bound="Login")
 
 @attr.s(auto_attribs=True)
 class Login:
-    """
-    Attributes:
-        email (str):
-        password (str):
-    """
+    """ """
 
     email: str
     password: str
