@@ -7,10 +7,7 @@ T = TypeVar("T", bound="ValidateIdJsonBody")
 
 @attr.s(auto_attribs=True)
 class ValidateIdJsonBody:
-    """
-    Attributes:
-        id (str):
-    """
+    """ """
 
     id: str
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
